@@ -13,7 +13,7 @@ class Cursor(BaseModel):
     """Current backtest position storage."""
 
     price: Decimal = Decimal(0)
-    ts: Time = Time.from_timestamp(0)
+    ts: Time = Time(0)
 
     def set(self, ts: datetime, price: Union[int, float, Decimal]):
         self.ts = Time.from_datetime(ts)
@@ -23,5 +23,7 @@ class Cursor(BaseModel):
     def patch_price(self, price: Decimal):
         _saved_price = self.price
         self.price = price
-        yield
-        self.price = _saved_price
+        try:
+            yield
+        finally:
+            self.price = _saved_price
