@@ -1,6 +1,7 @@
 from .colors import create_palette
 from .decimals import float_to_decimal, to_decimal
 from .environment import in_colab, in_notebook
+from .rate_limit import RateLimiter
 
 
 __all__ = (
@@ -8,5 +9,6 @@ __all__ = (
     "float_to_decimal",
     "in_colab",
     "in_notebook",
+    "RateLimiter",
     "to_decimal",
 )
